summaryrefslogtreecommitdiffstats
path: root/winsup/cygwin/miscfuncs.cc
diff options
context:
space:
mode:
Diffstat (limited to 'winsup/cygwin/miscfuncs.cc')
-rw-r--r--winsup/cygwin/miscfuncs.cc9
1 files changed, 5 insertions, 4 deletions
diff --git a/winsup/cygwin/miscfuncs.cc b/winsup/cygwin/miscfuncs.cc
index 2b3c6b879..4794d3145 100644
--- a/winsup/cygwin/miscfuncs.cc
+++ b/winsup/cygwin/miscfuncs.cc
@@ -898,10 +898,11 @@ err:
}
#ifdef __x86_64__
-/* These functions are almost verbatim NetBSD code, just wrapped in the
- minimum required code to make them work with the MS AMD64 ABI.
- See NetBSD src/lib/libc/amd64/string/memset.S
- and NetBSD src/lib/libc/amd64/string/bcopy.S */
+/* These functions are almost verbatim FreeBSD code (even if ther header of
+ one file mentioneds NetBSD), just wrapped in the minimum required code to
+ make them work with the MS AMD64 ABI.
+ See FreeBSD src/lib/libc/amd64/string/memset.S
+ and FreeBSD src/lib/libc/amd64/string/bcopy.S */
asm volatile (" \n\
/* \n\